@@ -22,10 +22,8 @@ def create_dataframe_from_file(file_path, delimiter=',', widths=None, has_header
 
     Examples:
     | Create Dataframe from file | /path/to/file.csv |
-    | Create Dataframe from file | /path/to/file.psv | delimiter='|' |
-    | Create Dataframe from file | /path/to/file.txt | widths=[10, 5, 8, 10], has_header=False, skiprows=[0, 1], skipfooter=1 |
-    | Create Dataframe from file | /path/to/file.dat | delimiter=' ' | widths=None, skipfooter=2 |
-    | Create Dataframe from file | /path/to/file.xlsx |
+    | Create Dataframe from file | /path/to/file.psv | delimiter='|', skiprows=[0], skipfooter=1 |
+    | Create Dataframe from file | /path/to/file.xlsx | skiprows=[0], skipfooter=2 |
 
     """
     # Determine the file type based on the file extension
@@ -46,25 +44,6 @@ def create_dataframe_from_file(file_path, delimiter=',', widths=None, has_header
             df = pd.read_csv(file_path, delimiter='|', skiprows=skiprows, skipfooter=skipfooter)
         else:
             df = pd.read_csv(file_path, delimiter='|', header=None, skiprows=skiprows, skipfooter=skipfooter)
-    elif file_ext == 'txt' or file_ext == 'dat':
-        if widths is None:
-            # Calculate field widths
-            logger.info(f"Step 1: Calculating field widths for fixed width file '{file_path}'")
-            with open(file_path, 'r') as f:
-                # Read the first line of the file to determine the number of columns
-                num_cols = len(f.readline().strip().split(delimiter))
-                # Calculate the width of each column by dividing the width of the file by the number of columns
-                width = int(f.tell() / num_cols)
-                # Set the widths parameter to a list of equal width integers
-                widths = [width] * num_cols
-                logger.info(f"Calculated widths: {widths}")
-        else:
-            logger.info(f"Step 1: Reading fixed width file '{file_path}' with widths {widths}")
-        # Read fixed width file into a DataFrame
-        if has_header:
-            df = pd.read_fwf(file_path, widths=widths, skiprows=[0], skipfooter=1)
-        else:
-            df = pd.read_fwf(file_path, widths=widths, header=None, skiprows=[0], skipfooter=1)
     elif file_ext == 'xlsx' or file_ext == 'xls':
         # Log info message
         logger.info(f"Step 1: Reading Excel file '{file_path}'")
@@ -81,6 +60,83 @@ def create_dataframe_from_file(file_path, delimiter=',', widths=None, has_header
 
     return df
 
+# @keyword(name="Create Dataframe from file")
+# def create_dataframe_from_file(file_path, delimiter=',', widths=None, has_header=True, skiprows=None, skipfooter=None):
+#     """
+#     Creates a Pandas DataFrame from a CSV, PSV, or fixed width file.
+#
+#     Parameters:
+#         file_path (str): The path to the input file.
+#         delimiter (str): The delimiter character used in the input file. Default is ','.
+#         widths (list of int): The field widths for each column in the input file. If None, calculate the field widths. Default is None.
+#         has_header (bool): Whether the input file has headers. Default is True.
+#         skiprows (list of int): Line numbers to skip at the start of the file.
+#         skipfooter (int): Number of lines to skip at the end of the file.
+#
+#     Returns:
+#         pandas.DataFrame: The DataFrame created from the input file.
+#
+#     Examples:
+#     | Create Dataframe from file | /path/to/file.csv |
+#     | Create Dataframe from file | /path/to/file.psv | delimiter='|' |
+#     | Create Dataframe from file | /path/to/file.txt | widths=[10, 5, 8, 10], has_header=False, skiprows=[0, 1], skipfooter=1 |
+#     | Create Dataframe from file | /path/to/file.dat | delimiter=' ' | widths=None, skipfooter=2 |
+#     | Create Dataframe from file | /path/to/file.xlsx |
+#
+#     """
+#     # Determine the file type based on the file extension
+#     file_ext = file_path.split('.')[-1].lower()
+#     if file_ext == 'csv':
+#         # Log info message
+#         logger.info(f"Step 1: Reading CSV file '{file_path}' with delimiter '{delimiter}'")
+#         # Read CSV file into a DataFrame
+#         if has_header:
+#             df = pd.read_csv(file_path, delimiter=delimiter)
+#         else:
+#             df = pd.read_csv(file_path, delimiter=delimiter, header=None)
+#     elif file_ext == 'psv':
+#         # Log info message
+#         logger.info(f"Step 1: Reading PSV file '{file_path}' with delimiter '|'")
+#         # Read PSV file into a DataFrame
+#         if has_header:
+#             df = pd.read_csv(file_path, delimiter='|', skiprows=skiprows, skipfooter=skipfooter)
+#         else:
+#             df = pd.read_csv(file_path, delimiter='|', header=None, skiprows=skiprows, skipfooter=skipfooter)
+#     elif file_ext == 'txt' or file_ext == 'dat':
+#         if widths is None:
+#             # Calculate field widths
+#             logger.info(f"Step 1: Calculating field widths for fixed width file '{file_path}'")
+#             with open(file_path, 'r') as f:
+#                 # Read the first line of the file to determine the number of columns
+#                 num_cols = len(f.readline().strip().split(delimiter))
+#                 # Calculate the width of each column by dividing the width of the file by the number of columns
+#                 width = int(f.tell() / num_cols)
+#                 # Set the widths parameter to a list of equal width integers
+#                 widths = [width] * num_cols
+#                 logger.info(f"Calculated widths: {widths}")
+#         else:
+#             logger.info(f"Step 1: Reading fixed width file '{file_path}' with widths {widths}")
+#         # Read fixed width file into a DataFrame
+#         if has_header:
+#             df = pd.read_fwf(file_path, widths=widths, skiprows=[0], skipfooter=1)
+#         else:
+#             df = pd.read_fwf(file_path, widths=widths, header=None, skiprows=[0], skipfooter=1)
+#     elif file_ext == 'xlsx' or file_ext == 'xls':
+#         # Log info message
+#         logger.info(f"Step 1: Reading Excel file '{file_path}'")
+#         # Read Excel file into a DataFrame
+#         if has_header:
+#             df = pd.read_excel(file_path, skiprows=skiprows, skipfooter=skipfooter)
+#         else:
+#             df = pd.read_excel(file_path, header=None, skiprows=skiprows, skipfooter=skipfooter)
+#     else:
+#         raise ValueError("Unsupported file type.")
+#
+#     # Log success message
+#     logger.info(f"Step 2: DataFrame created with shape {df.shape}")
+#
+#     return df
+
 
 @keyword("Write DataFrame to CSV file")
 def write_df_to_csv(df_to_write: pd.DataFrame, file_path: str, file_name: str, index: bool = False):
